@@ -5,7 +5,7 @@ package MarpaX::Java::ClassFile::Role::Parser::Actions;
 
 # ABSTRACT: Grammar actions role for .class file parsing
 
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
@@ -247,10 +247,11 @@ sub utf8 {
   #
   no warnings;
 
-  return unless (length($_[1]));
+  my $s = undef;
+  return $s unless (length($_[1]));
 
   my @bytes = unpack('C*', $_[1]);
-  my ($s, $val0, $val1, $val2, $val3, $val4, $val5) = '';
+  my ($val0, $val1, $val2, $val3, $val4, $val5) = '';
 
   while (@bytes) {
     #
@@ -313,7 +314,7 @@ MarpaX::Java::ClassFile::Role::Parser::Actions - Grammar actions role for .class
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 DESCRIPTION
 
@@ -325,7 +326,7 @@ Jean-Damien Durand <jeandamiendurand@free.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jean-Damien Durand.
+This software is copyright (c) 2016 by Jean-Damien Durand.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
